@@ -1,6 +1,4 @@
 Renvs= new.env()
-##this doesn't seem to work anyway...
-#if(getRversion() >= "2.15.1") globalVariables(".lib.loc")
 
 ##' switchTo
 ##'
@@ -91,7 +89,7 @@ setMethod("switchTo", c(name = "character", seed = "character"),
                 chtype = "repourl"
                 
             } else if (chtype == "manifesturl") {
-                if(requireNamespace("RCurl")) {
+                if(requireNamespace2("RCurl")) {
                     seed = strsplit(RCurl::getURL(seed), "\n")[[1]]
 
                 } else {
@@ -380,9 +378,10 @@ setMethod("attachedPkgs<-", "SwitchrCtx", function(seed, value) {
 setGeneric("announce", function(seed, reverted=FALSE) standardGeneric("announce"))
 
 setMethod("announce", "SwitchrCtx", function(seed, reverted=FALSE) {
-    message(sprintf("%s to the '%s' computing environment. %d packages are currently available.", ifelse(reverted, "Reverted", "Switched"),
+    message(sprintf("%s to the '%s' computing environment. \n%d packages are currently available.", ifelse(reverted, "Reverted", "Switched"),
                     seed@name,  nrow(seed@packages)))
-    message(sprintf("Packages installed in your site library ARE %ssuppressed.", ifelse(seed@exclude.site, "", "NOT ")))
+    if(seed@exclude.site)
+        message("Packages installed in your site library ARE suppressed.")
     message("To switch back to your previous environment type switchBack()")
 })
 
@@ -425,7 +424,6 @@ currentCompEnv = function() {
         }
 
 
-globalVariables(".lib.loc")
 
 .libPaths2 = function(fulllp, exclude.site=TRUE) {
     fun = .libPaths
