@@ -205,7 +205,7 @@ setMethod("makeSVNURL", "GitSource",
     
 findPkgVersionInBioc = function(name, version, param = SwitchrParam(), dir)
 {
-    if(!requireNamespace("BiocInstaller")) {
+    if(!requireNamespace2("BiocInstaller")) {
         warning("Unable to search bioconductor for package version because BiocInstaller is not available")
         return(NULL)
     }
@@ -221,8 +221,7 @@ findPkgVersionInBioc = function(name, version, param = SwitchrParam(), dir)
 
         if(!file.exists(dir))
             dir.create(dir, recursive=TRUE)
-        oldwd = getwd()
-        setwd(dir)
+        oldwd = setwd(dir)
         on.exit(setwd(oldwd))
         
         commit = findBiocSVNRev(name, version, destpath = dir,
@@ -330,23 +329,16 @@ findBiocSVNRev = function(name, version, destpath, param, biocVers="devel")
         if(!ret)
             return(NULL)
     }         
-
-
-    
-
-    
     findSVNRev(name, version, svn_repo = repoloc, pkgpath = pkgdir, param = param)
-    
-        
+
 }
 
 ## destpath is the actual package directory, not the general destpath for all pkgs.
 ## confusing, should change this.
 findSVNRev = function(name, version, svn_repo, pkgpath, param) {
 
-    oldwd = getwd()
     ##setwd(file.path(destpath,  name))
-    setwd(pkgpath)
+    oldwd = setwd(pkgpath)
     on.exit(setwd(oldwd))
     system_w_init(paste("svn switch --ignore-ancestry", svn_repo), param = param)
 
@@ -463,4 +455,45 @@ setMethod("gotoVersCommit", c(dir = "character", src= "BiocSource"),
           })
 
 
+##' @rdname gotoVersCommit
+##' @aliases gotoVersCommit,character,GitSource
+
+setMethod("gotoVersCommit", c(dir="character", src="GitSource"),
+          function(dir, src, version, param = SwitchrParam()) {
+
+              if(is.na(version))
+                  return(dir)
+              desc = read.dcf(file.path(dir, "DESCRIPTION"), all=TRUE)
+              if(compareVersion(version, desc$Version) == 0)
+                  return(dir)
+              ret = findGitRev(src@name, version = version, codir = dir)
+              dir
+          })
+
+
+findGitRev = function(pkg, version, codir, param = SwitchrParam()) {
+    if(!file.exists(file.path(codir, "DESCRIPTION")))
+        log("Couldn't find DESCRIPTION file in git checkout")
+    oldwd = setwd(codir)
+    on.exit(setwd(oldwd))
+    log = system_w_init("git log -p DESCRIPTION", intern = TRUE, param = param)
+    cpos = grep("commit [[:alnum:]]{40}[[:space:]]*$", log)
+    line = grep(paste("\\+[vV]ersion: *", version,"$", sep=""), log)
+    if(!length(line)) {
+        logfun(param)(pkg, sprintf("Version %s does not appear in the git commit logs on this branch. Searching across multiple branches is not currently supported", version))
+        return(NULL)
+    }
+    cpos = max(cpos[cpos<line])
+    sha = gsub("commit ([[:alnum:]]{40})[[:space:]]*$", "\\1", log[cpos])
+    cmd = sprintf("git checkout %s", sha)
+    res = tryCatch(system_w_init(cmd, param = param, intern=TRUE), error = function(e) e)
+    if(is(res, "error")) {
+        logfun(param)(pkg, sprintf("Found commit for package version but checking out that commit failed, cmd: %s",cmd), type = "both")
+        NULL
+    } else {
+        codir
+    }
+}
+
+
           
